<?php

/*
 * Plugin Name: DeMomentSomTres Promotions 
 * Plugin URI: http://www.demomentsomtres.com/
 * Description: Promotions custom post-type with expiration date
 * Version: 1.2
 * Author: Marc Queralt
 * Author URI: http://demomentsomtres.com
 * Change story
 * 1.0 - Initial version
 */

define('DMST_PROMOTIONS_DOMAIN', 'dmst-promotions');

load_plugin_textdomain(DMST_PROMOTIONS_DOMAIN, false, dirname(plugin_basename(__FILE__)) . 'languages');

add_action('init', 'dmst_create_promotions_post_type');
add_action('widgets_init', 'dmst_promotions_register_widget');

function dmst_create_promotions_post_type() {
    register_post_type(
            'promotions', array(
        'label' => __('Promotions', DMST_PROMOTIONS_DOMAIN),
        'description' => __('Time based promotions', DMST_PROMOTIONS_DOMAIN),
        'public' => true,
        'show_ui' => true,
        'show_in_menu' => true,
        'capability_type' => 'post',
        'hierarchical' => false,
        'rewrite' => array('slug' => 'promos'),
        'query_var' => true,
        'has_archive' => true,
        'menu_position' => 5,
        'supports' => array(
            'title',
            'editor',
            'excerpt',
            'trackbacks',
            'custom-fields',
            'comments',
            'revisions',
            'thumbnail',
            'author',
            'page-attributes',
        ),
        'taxonomies' => array('promo-type',),
        'labels' => array(
            'name' => __('Promotions', DMST_PROMOTIONS_DOMAIN),
            'singular_name' => __('Promotion', DMST_PROMOTIONS_DOMAIN),
            'menu_name' => __('Promotions', DMST_PROMOTIONS_DOMAIN),
            'add_new' => __('Add Promotion', DMST_PROMOTIONS_DOMAIN),
            'add_new_item' => __('Add New Promotion', DMST_PROMOTIONS_DOMAIN),
            'edit' => __('Edit', DMST_PROMOTIONS_DOMAIN),
            'edit_item' => __('Edit Promotion', DMST_PROMOTIONS_DOMAIN),
            'new_item' => __('New Promotion', DMST_PROMOTIONS_DOMAIN),
            'view' => __('View Promotion', DMST_PROMOTIONS_DOMAIN),
            'view_item' => __('View Promotion', DMST_PROMOTIONS_DOMAIN),
            'search_items' => __('Search Promotions', DMST_PROMOTIONS_DOMAIN),
            'not_found' => __('No Promotions Found', DMST_PROMOTIONS_DOMAIN),
            'not_found_in_trash' => __('No Promotions Found in Trash', DMST_PROMOTIONS_DOMAIN),
            'parent' => __('Parent Promotion', DMST_PROMOTIONS_DOMAIN),
        ),
            )
    );
    register_taxonomy(
            'promo-type', array(0 => 'promotions'), array(
        'hierarchical' => true,
        'label' => __('Promo Types', DMST_PROMOTIONS_DOMAIN),
        'show_ui' => true,
        'query_var' => true,
        'rewrite' => array('slug' => 'promotion-type'),
        'singular_label' => __('Promo Type', DMST_PROMOTIONS_DOMAIN),
            )
    );
}

function dmst_promotions_register_widget() {
    register_widget('dmst_promotions_widget');
}

class dmst_promotions_widget extends WP_Widget {

    function dmst_promotions_widget() {
        $widget_ops = array(
            'classname' => 'dmst_promotions_widget',
            'description' => __('Widget to show promotions', DMST_PROMOTIONS_DOMAIN),
        ); /* Widget settings. */
        $control_ops = array(
            'width' => 450,
            'height' => 250,
            'id_base' => 'dmst_promotions_widget',
        ); /* Widget control settings. */
        $this->WP_Widget('dmst_promotions_widget', __('Promotions Widget', DMST_PROMOTIONS_DOMAIN), $widget_ops, $control_ops); /* Create the widget. */
    }

    function update($new_instance, $old_instance) {
        $instance = $old_instance;
        foreach ($new_instance as $k => $v) {
            $instance[$k] = strip_tags($v);
        } /* Strip tags (if needed) and update the widget settings. */
        return $instance;
    }

    function form($instance) {
        /* Set up some default widget settings. */
        $defaults = array(
            'title' => __('Promotions', DMST_PROMOTIONS_DOMAIN)
        );
        $instance = wp_parse_args((array) $instance, $defaults);
        echo '<p><label for="' . $this->get_field_id('title') . '">' . 'Title' . '</label><br />
                                        <input type="text" id="' . $this->get_field_id('title') . '" name="' . $this->get_field_name('title') . '" value="' . $instance['title'] . '" /></p>';
    }

    function widget($args, $instance) {
        extract($args);
        echo $before_widget; /* Before widget (defined by themes). */
        if ($instance['title'])
            echo $before_title . $instance['title'] . $after_title; /* Title of widget (before and after defined by themes). */
        $qargs = array(
            'post_type' => 'promotions',
            'showposts' => 1,
        );
        $query = new WP_Query($qargs);
        if ($query->have_posts()):
            $p = $query->get_posts();
            $p = $p[0];
            echo '<div class="promotions-widget">';
            echo '<h3>' . $p->post_title . '</h3>';
            $text = $p->post_content;
            $text = str_replace("<h2>", "<p class='h2'>", $text);
            $text = str_replace("</h2>", "</p>", $text);
            echo apply_filters('the_content', $text);
            echo '</div><!--promotions-widget-->';
        endif;
        echo $after_widget; /* After widget (defined by themes). */
    }

}

?>